bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 31. Aventiure
___________________________________________________ #### Aventv wie die Herren ze kirchen giengen
| ### <Mir> chvolint so die ringe so sprach Volker ### ia wæn div naht vns welle nv niht wern mer ### ich chivsez von dem lvfte ez ist vil schiere tac ### do wachten si der manigen der noch slafende lach ### Do erschein der liehte morgen den gesten in den sal ### Hagen begunde vragen die rechen vber al ### ob si zem mvnster wolden zvo der messe gan ### nach siten kristenlichen man vil lvtten began
###### 1896 | ### Si svngen vngeliche daz da vil wol schein ### kristen vn– heiden die zvgen niht enein ### do wolden zv den chirchen die Guntheres man ### si warn von den betten al geliche nv gestan
###### 1897 | ### Do næten sich die rechen in also gvot gewant ### daz nie helde mere in deheines kuniges lant ### bezzer kleider brahten daz was Hagene leit ### er sprach ia svlt ir degene hie tragen anderiv kleit
###### 1898 | ### Nv sint iv doch genvogen div mære wol bechant ### nv traget fvr die rôsen div wafen an der hant ### fvr schapel wol gesteinet die liehten helme gvot ### sit wir so wol erchennen der argen Chriemh' mvot
###### 1899 | ### Wir mvzen hivte striten daz wil ich iv sagen ### ir svlt fvr siden hemde die liehten prvenne tragen ### vn– fvr die tiefen mæntil die vesten schilde wit ### ob iemen mit iv zvrne daz ir vil werliche sit
###### 1900 | ### Mine vil lieben herren darzvo mage vn– man ### ir svlt vil willechliche zvo der chirchen gan ### vn– chlaget got dem richen sorge un– iwer not ### vn– wizzet sicherlichen daz vns na [67v]het der tot
###### 1901 | ### Irn svlt ovch niht vergezzen swaz ir habt getan ### vn– svlt vil vlegeliche da gegen gote <stan> ### ir svlt sin gewarnet recken also her ### ez enwelle got von himele ir vernemt messe nimmer mer
| ### Svs giengen zv dem mvnster die fvrsten vn– ir man ### vf den vronen chirchof do hiez si stille stan ### Hagene der chvene daz si sich schieden niht ### er sprach iane <weiz> noch niemen waz von den Hvnen vns
###### 1903 | ### Leget mine frivnde die schilde fvr den fvoz [ geschiht ### vn– geltet ob iv iemen biete swachen grvoz ### mit tiefen verchwnden daz ist Hagenen rat ### daz ir so werdet fvnden daz ez iv lobelichen stat
###### 1904 | ### Volker vn– Hagene die zwene giengen dan ### fvr daz mvnster daz wart dvrch daz getan ### daz si daz wolden wizzen daz des kuniges wip ### mit in da mvese dringen ia was vil grimmech ir lip
###### 1905 | ### Do chom der wirt des landes vnt ovch sin schone wip ### mit vil richem gewande gezieret was ir lip ### der rechen genvoge die man sach mit ir varn ### do chos man hohe stovben von der kuniginne scharn
| ### Do der kunic Ezele alsvs gewaffent sach ### die rechen von dem Rine wie balde er do sprach ### wie sihe ich frivnde min vnder helmen gan ### mirst leit vf mine triwe vn– hat in iemen iht getan
###### 1907 | ### Ich sol in gerne bvzen swie si dvnchet gvot ### hat iemen in beswæret daz herce vn– ovch den mvot ### des bringe ich si wol innen daz ez mir ist vil leit ### swie si mir gebietent des bin ich alles in bereit
###### 1908 | ### Do sprach von Tronege Hagene vns hat niemen niht getan ### ez ist site miner herren daz si wafent gan ### zallen hochgeciten ze vollen drien tagen ### het vns iemen iht getan wir soldenz iv billiche sagen
###### 1909 | ### Wol hort div kuniginne waz Hagene sprach ### wie rehte vintliche si im vnder dovgen sach ### sine wolde doch niht melden die site von ir lant ### swie lange si sie da heime mit frevden hete bechant
###### 1910 | ### Swie grimme vn– ovch swie starche si in vient wære ### het iemen gesaget Ezelen div rehten mære ### er het iz vnderstanden daz niht da wære geschehn ### si liezenz dvrch ir vbermvot daz sis im wolden niht veriehn
| ### Do gie div kuniginne mit grozer menege dan ### done wolden dise zwene idoch niht hoher stan ### drier trite breiter daz was den Hvnen leit ### ia mvse si sich dringen mit den degenen gemeit
###### 1912 | ### Die Ezeln kamerære dvote daz niht gvot ### ia heten si den rechen erzvrnet do den mvot ### wan daz sine torsten vor dem kunige her ### da was vil michel dringen vn– doch niht <anders> mer
###### 1913 | ### Do man da gote gediente vnt [68r]da si wolden dan ### do chomen da zen rossen vil manic Hvnen man ### ovch was bi Chriemh' vil manic schoniv meit ### wol sibent tvsent degene bi der kuneginne reit
###### 1914 | ### In des sales venster Chriemh' gesaz ### mit maniger schonen frowen mit frevden ane haz ### Ezele der riche gesaz ovch zv zir nider ### vn– sahen kurcewile von den gvten rechen sider
| ### Nv was ovch in der marschalch mit den rossen chomen ### Danchwart der snelle er het zvo zim genomen ### sins herren ingesinde von Bvregonden lant ### div ros man wol gesatelet den ellenden rechen vant
###### 1916 | ### Do si zen rossen chomen die kunige vn– ir man ### Volker der chvene raten do began ### si solden bvhvrdieren nach ir landes siten ### des wart von degenen sit vil herlich geriten
###### 1917 | ### Vof den hof vil witen chom do manic man ### Ezele vn– Chriemh' ez sahen allez an ### der bvhvrt vn– schallen div beidiv wrden groz ### von kristen vn– von heiden wie lvzzil iemen da verdroz
###### 1918 | ### Vf den buhurt chomen al zehant geriten ### die Dietriches rechen in hochverteklichen siten ### si wolde kurcewile mit den gesten han ### do enwolde ers in niht gvnnen ir herre hiez siz balde lan
###### 1919 | ### Mit Guntheres mannen daz spil er in verbot ### er vorhte siner degene des gie im groziv not ### do chomen von Bechelaren die Rvdegeres man ### dar vmbe do der edele starche zvrnen began
###### 1920 | ### Er chom zvo zin vil balde gedrvngen dvrch die schar ### vn– sagete sinen degenen si wæren des gewar ### daz in vnmvte wæren die Gvnthers man ### ob si den bvhvrt liezen daz wære im liebe getan
| ### Do sich die von in schieden als vns ist geseit ### do chomen da von Dvringen helde vil gemeit ### vn– die von Tenemarchen wol tvsent chvner man ### von stichhen sah man vliegen vil der trvonzvone dan
###### 1922 | ### Hawart vnt ovch Irnfrit gesellechliche siten ### des waren die von Rine in hochvertiklichen siten ### si bvten manige tioste den von Dvringen lant ### des wart von stichen dvrchel vil manic herlicher rant
###### 1923 | ### Do chom ovch zv dem schalle der herre Bloedelin ### mit tusent siner rechen die taten da wol schin ### wie si riten chvnden sich hvop groz vngemach ### Chriemh' ez vil gerne dvrch leit der Bvregonde sach
###### 1924 | ### Si gedaht in ir mvote als ez was nach geschehn ### geschæhe iemen von in leide so moehte ich mich versehn ### daz ez erhaben wrde an den vienden min ### wrde ich wol errochen des wolde ich gar an angest sin
| ### Schrvotan vn– Gibeche vf den buhvrt riten ### Hornboge vn– Ramunch nach <hvnischen> siten ### si hielten gein den helden vz Buregonden lant ### die schefte dræten hohe mit chreften fvr des sales want
###### 1926 | ### Swes da iemen pflêge so was [68v]ez niwan schal ### man horte von schilde stozen palas vn– sal ### harte lvot erdiezen von Gunthers man ### den lop daz sin gesinde mit grozen eren da gewan
###### 1927 | ### Do was ir churcewile so lanc vn– ovch so groz ### daz dvrch die chovertivre der blanche sweiz do vloz ### von den vil gvten marchen die di helde riten ### si svohtenz an den Hvnen in vil hochvertlichen siten
###### 1928 | ### Do sprach der videlære Volker der chvne man ### ich wên vns dise rechen tvrren niht bestan ### ich hort ie sagen mære daz si vns trvgen haz ### nvne chvndez sich zer werlde zware nimmer fvegen baz
###### 1929 | ### Zen herbergen fveren sprach der kunec her ### sol man nv di moere vnde riten danne mer ### gegen abende so des wirdet cit ### waz ob div kuniginne lop den vnchunden git
| ### Do sahens eincn riten so waigerlichen hie ### daz ez al der Hvnen tet deheiner nie ### ia mohter in den venstern wol haben hercen trvot ### er was so wol gechleidet sam eins vil werden ritters brvot
###### 1931 | ### Do sprach aber Volker wie moehte ich daz verlan ### iener trvot der frowen mvz eine <gebvze> han ### daz chunde niemen wenden ez get im an den lip ### iane rvoche ich ob ez zvrne des kunic Ezeln wip
###### 1932 | ### Nein dvrch mine liebe sprach der kunec san ### ez wizzent vns die lvte ob wir si bestan ### ir lat ez heben die Hvnen daz fvget sich noch baz ### dannoch der kunec Ezele bi der kuniginne saz
###### 1933 | ### Ine mag es niht gelazen sprach do Volker ### den bvhvrt reit er widere mit vollechlicher ger ### stach er dem richen heiden daz sper dvrch sinen lip ### daz sah man sit beweinen beide maget vn– wip
###### 1934 | ### Do rvochte hvrtekliche Hagene nach im dan ### mit sehzich siner degene riten er began ### nach dem videlære da div tiost geschach ### Ezel vn– Chriemh' ez bescheidenliche sach
###### 1935 | ### Done wolden ovch die kunige den ir spileman ### bi den vianden niht ane helfe lan ### da wart von tvsent heleden vil chunsteklich geriten ### si taten daz si wolden in vil hochvertlichen siten
| ### Da der riche Hvne ze tode was erslagen ### man horte sine mage weinen vn– klagen ### do vragt al daz gesinde wer hat ez getan ### do sprachen die daz sahen daz hat der starche spileman
###### 1937 | ### Nach swerten vn– nach schilden riefen da zehant ### des marcgraven mage von der Hvnen lant ### do wolden si den spileman ze tode erslagen han ### der wirt vz eime venster sere gahen do began
###### 1938 | ### Do hvop sich von den lvten allenthalben schal ### die Guntheres rechen erbeizten vber al ### div ros ze rvcke stiezen die kunige vn– al ir man ### do chom der kunic Ezele der helt ez schaiden began
###### 1939 | ### Ein des Hvnen mage den er da bi im vant ### ein vil starchez wafen [69r]brach er im vz der hant ### do slvgers alle widere wan im was vil zorn ### wie het ich minen dienest an disen heleden verlorn
###### 1940 | ### Ob ir nv disen spileman het darvmbe erslagen ### ich hiez ivch alle hahen daz wil ich iv sagen ### ich sah vil wol sin riten do er den Hvnen stach ### deiz ane sinen willen von eime strvche geschach
###### 1941 | ### Ir mvzet mine geste vride lazen han ### do wart er geleite div ros div zoch man dan ### zv den herbergen si heten manigen kneht ### die in ze dienste waren mit allem vlize gereht
| ### Der wirt mit sinen frivnden in den palas gie ### zorn er mer deheinen da niht werden lie ### do rihte man die tische daz wazzer man in trvoc ### do heten die von Rine viende da genvoc
###### 1943 | ### Swie leit ez Ezeln wære gewafent manige schar ### sach man nach fvrsten dringen vn– wol ze vlizze gar ### da si zen tischen giengen dvrch der geste haz ### ir mâch si rechen wolden <ob> sich gefvgen chvnde daz
###### 1944 | ### Sit ir gewafent gerner ezzet danne bloz ### sprach der wirt des landes div vnzvht ist cze groz ### swer aber minen gesten hie tvot deheiniv leit ### ez get im an sin hovbet daz sie iv Hvnen geseit
###### 1945 | ### ê die herren gesezzen daz was hartelanch ### div Chriemh' sorge si al ze sere twanc ### si sprach herre Dietrich ich svches dinen rat ### helfe vn– genade min dinch mir angestlichen stat
###### 1946 | ### Do sprach fvr sinen herren Hildebrant der ellens rich ### swer sleht die Nibelunge der tvot ez ane mich ### dvrch deheines schazzes liebe ez mag im werden leit ### si sint noch vnbetwngen die snellen degene gemeit
| ### Si sprach ia hat mir Hagene also vil getan ### er morte Sivriden den minen lieben man ### der in vz den andern schiede dem wær min golt bereit ### engvltes ander iemen daz wær mir inneklichen leit
###### 1948 | ### Do sprach meister Hiltebrant wie chunde daz geschehn ### daz man in bi in slvge ich lieze ivch daz gesehn ### ob man den helt bestvnde sich hvbe liht ein not ### daz arme vn– riche dar vmbe mvsen ligen tot
###### 1949 | ### Do sprach in sinen zvehten dar zvo her Dietrich ### die bete la beliben kuniginne rich ### mir habent dine mage der leide niht getan ### daz ich die edeln degene mit strite welle bestan
###### 1950 | ### Div bet dich lvzzel eret vil edeles fvrsten lip ### daz dv dinen mâgen rætest an den lip ### si chomen vf genade her in dizze lant ### Sivrit ist vnerrochen von der Dietriches hant
###### 1951 | ### Do si an dem Bernære den willen niht envant ### do lobtes also balde an Bloedelines hant ### eine wite marche die Nvodvnch ê besaz ### sit do slvog in Danchwart daz er der gabe gar vergaz [69v]
| ### Si sprach dv solt mir helfen herre Bloedelin ### ez sint in disem hvose die viande min ### die Sivriden slvgen den minen lieben man ### der mir daz hilfet rechen dem bin ih immer vndertan
###### 1953 | ### Des anwrt ir Bloedel da er bi ir saz ### ia ne getarre ich dinen magen geraten cheinen haz ### wande si min brvoder bi im gerne siht ### ob ich si bestunde der kunec vertrvge mir sin niht
###### 1954 | ### Neyna herre Bloedel ich bin dir immer holt ### ia gib ich dir dar vmbe min silber vn– min golt ### vn– eine schone frowen daz Nvdvnges wip ### so mahtv gerne trvten den ir vil minneklichen lip
###### 1955 | ### Daz lant zvo den burgen soltv haben dir ### vil tivrlicher reche dv solt gelovben mir ### daz ich dich <sicherlichen> alles des gewer ### daz ich dir hie benennet han ob dv leistes mine ger
###### 1956 | ### Do der herre Bloedel die miete vernam ### vn– daz im dvrch ir schone div frowe wol gezam ### mit strite wander dienen daz minnekliche wip ### dar vmbe mvosen rechen mit im verliesen den lip
###### 1957 | ### Er sprach man sol geswigen der rede vber al ### ê man is <werde> inne so heb ich einen schal ### ez mvz arnen Hagene swaz er iv hat getan ### oder ich wil dar vmbe minen <lip> verlorn han
###### 1958 | ### Nv wafent ivch sprach Bloedel alle mine man ### wil svln den vianden in ir herberge gan ### des wil mich niht erlazen daz Ezeln wip ### dar vmbe svln wir degene alle wagen den lip
| ### Do div kuniginne Bloedelinen lie ### in des strites willen ze tische si do gie ### mit Ezele dem kunige vn– ovch mit sinen man ### si hete swinde ræte an die geste getan
###### 1960 | ### Wie si ze tische gienge daz wil ich iv sagen ### man sach da kunige riche chrone vor ir tragen ### vil manigen hohen fvrsten vn– manigen werden degn ### die sah man grozer zvhte vor der kuniginne pflegen
###### 1961 | ### Der wirt der schvf den gesten den sedel vber al ### den hohsten vn– den besten zvo zim in den sal ### den christen vn– den heiden ir spise er vnderschiet ### man gab genvoc in beiden als ez der wise kunec beriet
###### 1962 | ### Ir ander ingesinde zen herbergen azen ### den warn trvhsazen ze dienste lazen ### die mvsen ir spise wol ze vlize pflegen ### ir wirtschaft vn– ir frevde wart sit mit iamer widerwegen
| ### Do die fvrsten gesezzen warn vber al ### vn– nv begvnden ezzen do wart in den sal ### getragen zvo den fversten daz Ezeln kint ### da von der kunec riche gewan vil starchen iamer sint
###### 1964 | ### Dar giengen an der stvnde vier Ezeln man ### si trvogen Ortlieben den ivngen kunec dan ### zv der fvrsten tische da ovch Hagene saz ### des mvsiz kint ersterben dvrch sinen mortlichen haz
###### 1965 | ### Do [70r]der kunich riche sinen svon ersach ### zvo sinen chonemâgen er gvetliche sprach ### nv seht ir frivnde mine daz ist min einech man ### vn– ovch iwer swester der magiv noh vil dienste tvon
###### 1966 | ### Gevehter nach dem chvnne ein wirt ein kvne man ### rich vn– ovch vil edele starch vn– wolgetan ### leb ich deheine wile ich gib im drizzech lant ### so magiv wol gedienen des iungen Ortliebes hant
###### 1967 | ### Dar vmbe ich bite gerne ivch lieben frivnde min ### swenne ir ze lande widere ritet an den Rin ### so svlt ir mit iv fvren den iwern swester svon ### vn– svlt ovch an dem kinde vil genædekliche tvon
###### 1968 | ### Ziehet in zen erein vnz er werde ze man ### hat iv in den landen iemen iht getan ### daz hilfet er iv rechen daz habt vf minen lip ### die rede hort ovch Chriemh' des kunec Ezeln wip
| ### Im solden wol getrowen dise degene ### gewhser zeinem manne so sprach Hagene ### doch ist der kunec ivnge so veicklich getan ### man sol mich sehen selten ze hove nach Ortliebe gan
###### 1970 | ### Der kvnich Hagenen an blichte im was div rede leit ### swie niht dar vmbe en redete der fvrste vil gemeit ### ez betrvebte im sin herce vn– bewart im den mvot ### do was der Hagenen wille niht ze kurcewile gvot
###### 1971 | ### Ez tet den fvrsten allen mit dem kunige we ### daz Hagen von sime kinde het gesprochen ê ### daz siz versizzen solden daz was in vngemach ### sine wessen niht der mære waz von dem rechen sit geschach
###### 1972 | ### Gnvge di ez horten vn– im doch warn gram ### in heten gerne bestanden ovch het der kunec alsam ### getorster von sinen eren so wær ers chomen in not ### sit tet im Hagene mere er slvogen vor sinen ovgen tot

<<< Übersicht <<< vorige Seite nächste Seite >>>